%define uname dolphin

%define nightly 1
%if 0%{?nightly}
# Number comes from snapshot reference on dolphin-emu.org/download
# Use make-snapshot.sh to generate the tarball
# Use the latest beta snapshot version (pass commit hash to make-snapshot.sh)
# for a semblance of stability.
%define snapshot 16127
%endif

Name:           dolphin-emu
Version:        5.0%{?snapshot:.%{snapshot}}
Release:        %mkrel 1
License:        GPLv2+
Summary:        GameCube/Wii emulator
Url:            https://dolphin-emu.org
Group:          Emulators
%if 0%{?snapshot}
Source0:        %{uname}-%{version}.tar.xz
%else
Source0:        https://github.com/dolphin-emu/dolphin/archive/%{version}/%{uname}-%{version}.tar.gz
%endif
Source1:        make-snapshot.sh

# Updated bundled soundtouch to 2.1.2, fixes 9 CVEs.
# https://github.com/dolphin-emu/dolphin/pull/8725
Patch0:         dolphin-emu-pr-8725.patch

# (akien) Upstream does not support 32-bit platforms anymore.
# They used to work, but without JIT and thus not really useful to play games.
ExclusiveArch:  x86_64 aarch64

BuildRequires:  cmake
BuildRequires:  ffmpeg-devel
BuildRequires:  libgomp-devel
BuildRequires:  liblzo-devel
BuildRequires:  mbedtls-devel
# Could be used (with -DUSE_MGBA=ON) if code is added to use system lib.
#BuildRequires:  mgba-devel
BuildRequires:  miniupnpc-devel
BuildRequires:  pugixml-devel
BuildRequires:  sndio-devel
BuildRequires:  pkgconfig(ao)
BuildRequires:  pkgconfig(bluez)
BuildRequires:  pkgconfig(fmt) <= 8.1.1
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(hidapi-hidraw)
BuildRequires:  pkgconfig(libcurl)
# Upstream is going to fork enet while trying to stay protocol compatible
# https://github.com/comex/dolphin/commit/eb234da67fef01ffbcf1ae87dce8872cbf451162
# Might want to reconsider building against the shared version in the future
BuildRequires:  pkgconfig(libenet)
BuildRequires:  pkgconfig(libevdev)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(sfml-network)

# Modified upstream to use short instead of float and disable exceptions.
Provides:       bundled(soundtouch) = 2.1.2

%description
Dolphin is an emulator for two recent Nintendo video game consoles:
the GameCube and the Wii. It allows PC gamers to enjoy games for these
two consoles in full HD (1080p) with several enhancements: compatibility
with all PC controllers, turbo speed, networked multiplayer, and even more!

%prep
%autosetup -p1 -n %{uname}-%{version}

%build
%cmake -DDOLPHIN_WC_REVISION=%{!?snapshot:0}%{?snapshot:%{snapshot}} \
       -DUSE_SHARED_ENET=ON \
       -DENABLE_QT2=ON \
       -DENABLE_WX=OFF \
       -DUSE_MGBA=OFF \
       -DISTRIBUTOR=%{vendor} \
       -DBUILD_SHARED_LIBS=OFF
%cmake_build

%install
%cmake_install

# Thirdparty library, no need to have it installed
rm -f %{buildroot}%{_includedir}/discord_{register,rpc}.h
rm -f %{buildroot}%{_libdir}/libdiscord-rpc.a

%find_lang %{name}

%files -f %{name}.lang
%doc Readme.md
%{_bindir}/%{name}
%{_bindir}/%{name}-nogui
%{_bindir}/dolphin-tool
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.*
%{_mandir}/man6/%{name}*.6*


%changelog
* Fri Oct 27 2023 tex - 5.0.16127-1pclos2023
- new verision for 15.0.6
